The following files are firmware images that should work on most
ESP32-C3-based boards with 4MiB of flash, including WROOM and MINI modules,
that use the revision 3 silicon (or newer).

USB serial/JTAG support is enabled on pin 18 and 19. Note that this
is not a full USB stack, the C3 just provides a CDC/ACM class serial
and JTAG interface.
